<?php
/**
 * Custom template functions for this theme.
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */

/**
 * Custom edit comment link.
 *
 * @param string[] $output Array of comment edit links.
 */
function idsktmp_edit_comment_link( $output ) {
	$myclass = 'govuk-link govuk-!-margin-bottom-0';
	return preg_replace( '/comment-edit-link/', 'comment-edit-link ' . $myclass, $output, 1 );
}
add_filter( 'edit_comment_link', 'idsktmp_edit_comment_link' );

/**
 * Custom reply comment link.
 *
 * @param string[] $output Array of comment reply links.
 */
function idsktmp_reply_comment_link( $output ) {
	$myclass = 'govuk-button govuk-!-margin-bottom-0';
	return preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $myclass, $output, 1 );
}
add_filter( 'comment_reply_link', 'idsktmp_reply_comment_link' );

/**
 * Custom comment form fields.
 *
 * @param string[] $fields Array of the default comment fields.
 *
 * @return string[] Array of custom comment fields.
 */
function idsktmp_comment_form( $fields ) {
	// Get variables used in the field array.
	$req       = get_option( 'require_name_email' );
	$html_req  = $req ? " required='required'" : '';
	$html5     = current_theme_supports( 'html5', 'comment-form' );
	$commenter = wp_get_current_commenter();
	$consent   = ! empty( $commenter['comment_author_email'] ) ? ' checked="checked"' : '';

	// Modify the author field.
	$fields['author'] = '<div class="govuk-form-group">
			<label class="govuk-label" for="author">' . esc_html__( 'Name', 'idsk-template' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label>
			<input class="govuk-input" id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" maxlength="245"' . $html_req . ' />
		</div>';

	// Modify the email field.
	$fields['email'] = '<div class="govuk-form-group">
			<label class="govuk-label" for="email">' . esc_html__( 'Email', 'idsk-template' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label>
			<input class="govuk-input" id="email" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_email'] ) . '" maxlength="100" aria-describedby="email-notes"' . $html_req . ' />
		</div>';

	// Modify the url field.
	$fields['url'] = '<div class="govuk-form-group">
			<label class="govuk-label" for="url">' . esc_html__( 'Website address', 'idsk-template' ) . '</label>
			<input class="govuk-input" id="url" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_url'] ) . '" maxlength="200"' . $html_req . ' />
		</div>';

	// Modify the cookies field.
	$fields['cookies'] = '<div class="govuk-form-group">
			<div class="govuk-checkboxes">
				<div class="govuk-checkboxes__item">
					<input class="govuk-checkboxes__input" id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes"' . $consent . ' />
					<label class="govuk-label govuk-checkboxes__label" for="wp-comment-cookies-consent">' . esc_html__( 'Save my name, email and webpage in this browser for my future comments.', 'idsk-template' ) . '</label>
				</div>
			</div>
		</div>';

	return $fields;
}
add_filter( 'comment_form_default_fields', 'idsktmp_comment_form' );

/**
 * Custom comment textarea.
 *
 * @param array $defaults The default comment form arguments.
 *
 * @return array New comment form arguments.
 */
function idsktmp_comment_form_defaults( $defaults ) {
	$defaults['title_reply_before'] = '<h2 id="reply-title" class="govuk-heading-m">';
	$defaults['title_reply_after']  = '</h2>';

	$defaults['comment_field'] = '<div class="govuk-form-group">
			<label class="govuk-label" for="comment">' . esc_html__( 'Comment', 'idsk-template' ) . ' <span class="required">*</span></label> 
			<textarea class="govuk-textarea" id="comment" name="comment" rows="5" maxlength="65525" required="required"></textarea>
		</div>';

	return $defaults;
}
add_filter( 'comment_form_defaults', 'idsktmp_comment_form_defaults' );

/**
 * Reorder comment fields.
 *
 * @param array $fields Array of the default comment fields.
 *
 * @return array New comment fields order.
 */
function idsktmp_comment_form_fields( $fields ) {
	$comment_field = $fields['comment'];
	$author_field  = $fields['author'];
	$email_field   = $fields['email'];
	$url_field     = $fields['url'];
	$cookies_field = $fields['cookies'];
	unset( $fields['comment'] );
	unset( $fields['author'] );
	unset( $fields['email'] );
	unset( $fields['url'] );
	unset( $fields['cookies'] );
	$fields['author']  = $author_field;
	$fields['email']   = $email_field;
	$fields['url']     = $url_field;
	$fields['comment'] = $comment_field;
	$fields['cookies'] = $cookies_field;

	return $fields;
}
add_filter( 'comment_form_fields', 'idsktmp_comment_form_fields' );

/**
 * Custom post category in breadcrumbs.
 *
 * @param string $thelist List of categories for the current post.
 *
 * @return string List of categories for the current post.
 */
function idsktmp_breadcrumb_category( $thelist ) {
	$categories = get_the_category();

	if ( ! $categories || is_wp_error( $categories ) ) {
		return $thelist;
	}

	$output = '';
	foreach ( $categories as $category ) {
		$output .= '<li class="category-' . esc_attr( $category->slug ) . ' govuk-breadcrumbs__list-item">
				<a class="govuk-breadcrumbs__link" href="' . esc_url( get_category_link( $category->term_id ) ) . '">' . esc_html( $category->name ) . '</a>
			</li>';
	}

	return $output;
}
add_filter( 'the_category', 'idsktmp_breadcrumb_category' );

/**
 * Custom excerpt more.
 *
 * @param string $more The string shown within the more link.
 *
 * @return string The string shown within the more link.
 */
function idsktmp_excerpt_more( $more ) {
	return '...';
}
add_filter( 'excerpt_more', 'idsktmp_excerpt_more' );
